==> node-sdk-0.1.18.tgz: package/esm/internal/schema.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SendSchemaRequest } from "@streamdal/protos/protos/sp_internal";
import { audienceKey, internal } from "./register.js";
export const sendSchema = ({ configs, audience, pipelineStatus, }) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const step = pipelineStatus.stepStatuses.at(-1);
        if ((step === null || step === void 0 ? void 0 : step.stepName) !== "Infer Schema") {
            return;
        }
        if (!step.schema) {
            console.info("No schema found, skipping send schema");
            return;
        }
        const key = audienceKey(audience);
        const existing = internal.schemas.get(key);
        if (!existing || existing.toString() !== step.schema.toString()) {
            internal.schemas.set(key, step.schema);
            const schemaRequest = SendSchemaRequest.create({
                audience,
                schema: { jsonSchema: step.schema },
            });
            console.debug("sending schema...");
            const call = configs.grpcClient.sendSchema(schemaRequest, {
                meta: { "auth-token": configs.streamdalToken },
            });
            yield call.headers;
            console.debug("schema sent");
        }
    }
    catch (e) {
        console.error("Error sending schema", e);
    }
});

==> node-sdk-0.1.21.tgz: package/esm/internal/schema.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SendSchemaRequest } from "@streamdal/protos/protos/sp_internal";
import { audienceKey, internal } from "./register.js";
export const sendSchema = ({ configs, audience, schema, }) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (!schema) {
            console.info("No schema found, skipping send schema");
            return;
        }
        const key = audienceKey(audience);
        const existing = internal.schemas.get(key);
        if (!existing || existing.toString() !== schema.toString()) {
            internal.schemas.set(key, schema);
            const schemaRequest = SendSchemaRequest.create({
                audience,
                schema: { jsonSchema: schema },
            });
            console.debug("sending schema...");
            const call = configs.grpcClient.sendSchema(schemaRequest, {
                meta: { "auth-token": configs.streamdalToken },
            });
            yield call.headers;
            console.debug("schema sent");
        }
    }
    catch (e) {
        console.error("Error sending schema", e);
    }
});
